@@ -40,7 +40,7 @@ image_gif_read_buf(GifFileType *gif, GifByteType *data, int len)
         return 0;
       }
 
-      DEBUG_TRACE("  Reading %d bytes of SV data @ %d\n", sv_readlen, im->sv_offset);    
+      DEBUG_TRACE("  Reading %d bytes of SV data @ %d\n", sv_readlen, im->sv_offset);
       buffer_append(im->buf, SvPVX(im->sv_data) + im->sv_offset, sv_readlen);
       im->sv_offset += sv_readlen;
      }
@@ -48,7 +48,7 @@ image_gif_read_buf(GifFileType *gif, GifByteType *data, int len)
 
   memcpy(data, buffer_ptr(im->buf), len);
   buffer_consume(im->buf, len);
-  
+
   return len;
 }
 
@@ -60,16 +60,19 @@ image_gif_read_header(image *im)
 #else
   im->gif = DGifOpen(im, image_gif_read_buf);
 #endif
-  
+
   if (im->gif == NULL) {
+#ifdef GIFLIB_API_41
+    PrintGifError();
+#endif
     warn("Image::Scale unable to open GIF file (%s)\n", SvPVX(im->path));
     image_gif_finish(im);
     return 0;
   }
-  
+
   im->width  = im->gif->SWidth;
   im->height = im->gif->SHeight;
-  
+
   return 1;
 }
 
@@ -90,12 +93,12 @@ image_gif_load(image *im)
 
   temp_save.ExtensionBlocks = NULL;
   temp_save.ExtensionBlockCount = 0;
-  
+
   // If reusing the object a second time, start over
   if (im->used) {
     DEBUG_TRACE("Recreating giflib objects\n");
     image_gif_finish(im);
-    
+
     if (im->fh != NULL) {
       // reset file to begining of image
       PerlIO_seek(im->fh, im->image_offset, SEEK_SET);
@@ -104,46 +107,46 @@ image_gif_load(image *im)
       // reset SV read
       im->sv_offset = im->image_offset;
     }
-    
+
     buffer_clear(im->buf);
-    
+
     image_gif_read_header(im);
   }
-  
-  do { 
+
+  do {
     if (DGifGetRecordType(im->gif, &RecordType) == GIF_ERROR) {
       warn("Image::Scale unable to read GIF file (%s)\n", SvPVX(im->path));
       image_gif_finish(im);
       return 0;
     }
-    
+
     switch (RecordType) {
-      case IMAGE_DESC_RECORD_TYPE:      
+      case IMAGE_DESC_RECORD_TYPE:
         if (DGifGetImageDesc(im->gif) == GIF_ERROR) {
           warn("Image::Scale unable to read GIF file (%s)\n", SvPVX(im->path));
           image_gif_finish(im);
           return 0;
         }
-        
+
         sp = &im->gif->SavedImages[im->gif->ImageCount - 1];
-        
+
         im->width  = sp->ImageDesc.Width;
         im->height = sp->ImageDesc.Height;
-        
+
         BackGround = im->gif->SBackGroundColor; // XXX needed?
         ColorMap = im->gif->Image.ColorMap ? im->gif->Image.ColorMap : im->gif->SColorMap;
-        
+
         if (ColorMap == NULL) {
           warn("Image::Scale GIF image has no colormap (%s)\n", SvPVX(im->path));
           image_gif_finish(im);
           return 0;
         }
-        
+
         // Allocate storage for decompressed image
         image_alloc(im, im->width, im->height);
-        
+
         New(0, line, im->width, GifPixelType);
-        
+
         if (im->gif->Image.Interlace) {
           int i;
           for (i = 0; i < 4; i++) {
@@ -154,7 +157,7 @@ image_gif_load(image *im)
                 image_gif_finish(im);
                 return 0;
               }
-              
+
               for (y = 0; y < im->width; y++) {
                 ColorMapEntry = &ColorMap->Colors[line[y]];
                 im->pixbuf[ofs++] = COL_FULL(
@@ -165,9 +168,9 @@ image_gif_load(image *im)
                 );
               }
             }
-          }                
+          }
         }
-        else {        
+        else {
           ofs = 0;
           for (x = 0; x < im->height; x++) {
             if (DGifGetLine(im->gif, line, 0) != GIF_OK) {
@@ -175,7 +178,7 @@ image_gif_load(image *im)
               image_gif_finish(im);
               return 0;
             }
-    
+
             for (y = 0; y < im->width; y++) {
               ColorMapEntry = &ColorMap->Colors[line[y]];
               im->pixbuf[ofs++] = COL_FULL(
@@ -187,17 +190,17 @@ image_gif_load(image *im)
             }
           }
         }
-        
-        Safefree(line);     
+
+        Safefree(line);
         break;
-      
+
       case EXTENSION_RECORD_TYPE:
         if (DGifGetExtension(im->gif, &ExtFunction, &ExtData) == GIF_ERROR) {
           warn("Image::Scale unable to read GIF file (%s)\n", SvPVX(im->path));
           image_gif_finish(im);
           return 0;
         }
-        
+
         if (ExtFunction == 0xF9) { // transparency info
           if (ExtData[1] & 1)
             trans_index = ExtData[4];
@@ -206,7 +209,7 @@ image_gif_load(image *im)
           im->has_alpha = 1;
           DEBUG_TRACE("GIF transparency index: %d\n", trans_index);
         }
-        
+
         while (ExtData != NULL) {
           /* Create an extension block with our data */
 #ifdef GIFLIB_API_50
@@ -214,6 +217,9 @@ image_gif_load(image *im)
 #else
           temp_save.Function = ExtFunction;
           if (AddExtensionBlock(&temp_save, ExtData[0], &ExtData[1]) == GIF_ERROR) {
+#endif
+#ifdef GIFLIB_API_41
+            PrintGifError();
 #endif
             warn("Image::Scale unable to read GIF file (%s)\n", SvPVX(im->path));
             image_gif_finish(im);
@@ -221,21 +227,24 @@ image_gif_load(image *im)
           }
 
           if (DGifGetExtensionNext(im->gif, &ExtData) == GIF_ERROR) {
+#ifdef GIFLIB_API_41
+            PrintGifError();
+#endif
             warn("Image::Scale unable to read GIF file (%s)\n", SvPVX(im->path));
             image_gif_finish(im);
             return 0;
           }
-          
+
           ExtFunction = 0; // CONTINUE_EXT_FUNC_CODE
         }
         break;
-        
+
       case TERMINATE_RECORD_TYPE:
       default:
         break;
     }
   } while (RecordType != TERMINATE_RECORD_TYPE);
-  
+
   return 1;
 }
 
@@ -247,11 +256,14 @@ image_gif_finish(image *im)
     if (DGifCloseFile(im->gif, NULL) != GIF_OK) {
 #else
     if (DGifCloseFile(im->gif) != GIF_OK) {
+#endif
+#ifdef GIFLIB_API_41
+      PrintGifError();
 #endif
       warn("Image::Scale unable to close GIF file (%s)\n", SvPVX(im->path));
     }
     im->gif = NULL;
-    
+
     DEBUG_TRACE("image_gif_finish\n");
   }
 }
